bayespy.inference.vmp.nodes.expfamily.ExponentialFamilyDistribution.compute_message_to_parent
=============================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamilyDistribution.compute_message_to_parent